@@ -3,14 +3,13 @@ package Dist::Zilla::PluginBundle::Author::SKIRMESS;
 use strict;
 use warnings;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
 
 with qw(
   Dist::Zilla::Role::PluginBundle::Easy
-  Dist::Zilla::Role::BundleDeps
 );
 
 sub configure {
@@ -46,6 +45,7 @@ sub configure {
             {
                 ':version'       => '2.016',
                 exclude_filename => [qw( cpanfile dist.ini INSTALL LICENSE Makefile.PL META.json META.yml README.md )],
+                include_dotfiles => 1,
             }
         ],
 
@@ -89,7 +89,7 @@ sub configure {
         [
             'PruneCruft',
             {
-                exclude => [qw( .perltidyrc )],
+                except => [qw( \.perltidyrc )],
             }
         ],
 
@@ -156,18 +156,6 @@ sub configure {
             }
         ],
 
-        # Add Dist::Zilla authordeps to META files as develop prereqs
-        'Prereqs::AuthorDeps',
-
-        # List simple prerequisites
-        [
-            'Prereqs',
-            {
-                '-phase'          => 'develop',
-                $self->meta->name => $self->VERSION,
-            }
-        ],
-
         # Summarize Dist::Zilla configuration into distmeta
         'MetaConfig',
 
@@ -316,7 +304,7 @@ Dist::Zilla::PluginBundle::Author::SKIRMESS - Dist::Zilla configuration the way
 
 =head1 DESCRIPTION
 
-This is a L<Dist::Zilla> PluginBundle.
+This is a L<Dist::Zilla|Dist::Zilla> PluginBundle.
 
 =head1 USAGE
 
@@ -353,10 +341,10 @@ This is free software, licensed under:
 
 =head1 SEE ALSO
 
-L<Dist::Zilla::PluginBundle::Author::ETHER>,
-L<Dist::Zilla::PluginBundle::DAGOLDEN>,
-L<Dist::Zilla::PluginBundle::Milla>,
-L<Dist::Milla>
+L<Dist::Zilla::PluginBundle::Author::ETHER|Dist::Zilla::PluginBundle::Author::ETHER>,
+L<Dist::Zilla::PluginBundle::DAGOLDEN|Dist::Zilla::PluginBundle::DAGOLDEN>,
+L<Dist::Zilla::PluginBundle::Milla|Dist::Zilla::PluginBundle::Milla>,
+L<Dist::Milla|Dist::Milla>
 
 =cut
 
